@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: (GPL-2.0 OR BSD-2-Clause)
 
-ALL_TESTS="test_link_so test_link_a test_old_dispatcher test_xdp_frags test_xsk_prog_refcnt_bpffs test_xsk_prog_refcnt_legacy test_xsk_non_privileged test_link_detach"
+ALL_TESTS="test_link_so test_link_a test_old_dispatcher test_xdp_frags test_xsk_prog_refcnt_bpffs test_xsk_prog_refcnt_legacy test_xsk_non_privileged test_link_detach test_xsk_umem_flags"
 
 TESTS_DIR=$(dirname "${BASH_SOURCE[0]}")
 
@@ -112,6 +112,13 @@ test_link_detach()
 	ip link delete xdp_veth0
 }
 
+test_xsk_umem_flags()
+{
+	ip link add xdp_veth0 type veth peer name xdp_veth1
+	check_run $TESTS_DIR/test_xsk_umem_flags xdp_veth0
+	ip link delete xdp_veth0
+}
+
 cleanup_tests()
 {
     ip link del dev xdp_veth_big0 >/dev/null 2>&1
