@@ -9,21 +9,31 @@
 #define DEFAULT_QUEUE_IDS 64
 
 struct {
-        __uint(type, BPF_MAP_TYPE_XSKMAP);
-        __uint(key_size, sizeof(int));
-        __uint(value_size, sizeof(int));
+	__uint(type, BPF_MAP_TYPE_XSKMAP);
+	__uint(key_size, sizeof(int));
+	__uint(value_size, sizeof(int));
 	__uint(max_entries, DEFAULT_QUEUE_IDS);
 } xsks_map SEC(".maps");
 
 struct {
-        __uint(priority, 20);
+	__uint(priority, 20);
 	__uint(XDP_PASS, 1);
 } XDP_RUN_CONFIG(xsk_def_prog);
 
+/* Program refcount, in order to work properly,
+ * must be declared before any other global variables
+ * and initialized with '1'.
+ */
+volatile int refcnt = 1;
+
 /* This is the program for post 5.3 kernels. */
 SEC("xdp")
 int xsk_def_prog(struct xdp_md *ctx)
 {
+	/* Make sure refcount is referenced by the program */
+	if (!refcnt)
+		return XDP_PASS;
+
 	/* A set entry here means that the corresponding queue_id
 	 * has an active AF_XDP socket bound to it.
 	 */
