@@ -25,7 +25,7 @@ ALL_TESTS=""
 VERBOSE_TESTS=${V:-0}
 NUM_NS=2
 
-NEEDED_TOOLS="capinfos ethtool ip ping sed tc tcpdump timeout nc tshark"
+NEEDED_TOOLS="capinfos ethtool ip ping sed tc tcpdump timeout tshark nft socat"
 
 if [ -f "$TEST_CONFIG" ]; then
     source "$TEST_CONFIG"
@@ -472,12 +472,13 @@ else
     fi
 fi
 
-export XDP_FILTER
-export XDP_LOADER
+export XDPDUMP
 export XDP_BENCH
+export XDP_FILTER
+export XDP_FORWARD
+export XDP_LOADER
 export XDP_MONITOR
 export XDP_TRAFFICGEN
-export XDPDUMP
 
 TEST_DEFINITIONS="${1:-}"
 [ -f "$TEST_DEFINITIONS" ] || usage
